package com.ruoyi.nanjing.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.nanjing.mapper.TBdLinetypeMapper;
import com.ruoyi.nanjing.domain.TBdLinetype;
import com.ruoyi.nanjing.service.ITBdLinetypeService;
import com.ruoyi.common.core.text.Convert;

/**
 * 主支线管理Service业务层处理
 * 
 * @author limy
 * @date 2021-01-22
 */
@Service
public class TBdLinetypeServiceImpl implements ITBdLinetypeService 
{
    @Autowired
    private TBdLinetypeMapper tBdLinetypeMapper;

    /**
     * 查询主支线管理
     * 
     * @param LineID 主支线管理ID
     * @return 主支线管理
     */
    @Override
    public TBdLinetype selectTBdLinetypeById(Long LineID)
    {
        return tBdLinetypeMapper.selectTBdLinetypeById(LineID);
    }

    /**
     * 查询主支线管理列表
     * 
     * @param tBdLinetype 主支线管理
     * @return 主支线管理
     */
    @Override
    public List<TBdLinetype> selectTBdLinetypeList(TBdLinetype tBdLinetype)
    {
        return tBdLinetypeMapper.selectTBdLinetypeList(tBdLinetype);
    }

    /**
     * 新增主支线管理
     * 
     * @param tBdLinetype 主支线管理
     * @return 结果
     */
    @Override
    public int insertTBdLinetype(TBdLinetype tBdLinetype)
    {
        return tBdLinetypeMapper.insertTBdLinetype(tBdLinetype);
    }

    /**
     * 修改主支线管理
     * 
     * @param tBdLinetype 主支线管理
     * @return 结果
     */
    @Override
    public int updateTBdLinetype(TBdLinetype tBdLinetype)
    {
        return tBdLinetypeMapper.updateTBdLinetype(tBdLinetype);
    }

    /**
     * 删除主支线管理对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTBdLinetypeByIds(String ids)
    {
        return tBdLinetypeMapper.deleteTBdLinetypeByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除主支线管理信息
     * 
     * @param LineID 主支线管理ID
     * @return 结果
     */
    @Override
    public int deleteTBdLinetypeById(Long LineID)
    {
        return tBdLinetypeMapper.deleteTBdLinetypeById(LineID);
    }
}
